==> xoonips-3.46a.tar.gz: xoonips-3.46a/xoonips/class/xoonipsresponse.class.php <==
<?php
// $Revision: 1.1.4.1.2.3 $
// ------------------------------------------------------------------------- //
//  XooNIps - Neuroinformatics Base Platform System                          //
//  Copyright (C) 2005-2011 RIKEN, Japan All rights reserved.                //
//  http://xoonips.sourceforge.jp/                                           //
// ------------------------------------------------------------------------- //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
// ------------------------------------------------------------------------- //

include_once dirname( __FILE__ ) . '/xoonipserror.class.php';

/**
 *
 * @brief Class that have results of a logic
 * @see XooNIpsError
 *
 * @li set or get a result(success or fault) using get/setResult methods
 * @li set or get error informations using get/setError methods(only if failed)
 * @li set or get response of logic using set/getSuccess(only if succeed)
 *
 */
class XooNIpsResponse
{

    /**
     *
     * result of logic
     */
    var $result = false;

    /**
     *
     * response of logic
     */
    var $success = false;

    /**
     *
     * error information of logic
     */
    var $error = false;

    /**
     * create XooNIpsResponse
     */
    function XooNIpsResponse() 
    {
        $this->error = new XooNIpsError();
    }

    /**
     * @brief get result
     * @return boolean false if failed
     */
    function getResult() 
    {
        return $this->result;
    }

    /**
     * @brief get response of logic if succeed.
     * @return mixed response of logic
     */
    function &getSuccess() 
    {
        return $this->success;
    }

    /**
     * @brief get error informatino of logic if failed.
     * @return XooNIpsError error
     */
    function &getError() 
    {
        return $this->error;
    }
    
    /**
     * @brief add error code and error message
     * @param int $code error code
     * @param string $extra extra information of err(null if omitted)
     */
    function addError($code, $extra = null){
        $this->error -> add( $code, $extra);
    }
    
    /**
     * @brief set error informatino of logic if failed.
     * @param boolean $result
     */
    function setResult($result) 
    {
        $this->result = $result;
    }

    /**
     * @brief set error informatino of logic if failed.
     * @param mixed $success
     */
    function setSuccess(&$success) 
    {
        $this->success = &$success;
    }
}
?>

==> xoonips-3.49.tar.gz: xoonips-3.49/xoonips/class/xoonipsresponse.class.php <==
<?php

// ------------------------------------------------------------------------- //
//  XooNIps - Neuroinformatics Base Platform System                          //
//  Copyright (C) 2005-2011 RIKEN, Japan All rights reserved.                //
//  http://xoonips.sourceforge.jp/                                           //
// ------------------------------------------------------------------------- //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
// ------------------------------------------------------------------------- //

require_once __DIR__.'/xoonipserror.class.php';

/**
 * @brief Class that have results of a logic
 *
 * @see XooNIpsError
 *
 * @li set or get a result(success or fault) using get/setResult methods
 * @li set or get error informations using get/setError methods(only if failed)
 * @li set or get response of logic using set/getSuccess(only if succeed)
 */
class XooNIpsResponse
{
    /**
     * result of logic.
     */
    public $result = false;

    /**
     * response of logic.
     */
    public $success = false;

    /**
     * error information of logic.
     */
    public $error = false;

    /**
     * create XooNIpsResponse.
     */
    public function __construct()
    {
        $this->error = new XooNIpsError();
    }

    /**
     * @brief get result
     *
     * @return bool false if failed
     */
    public function getResult()
    {
        return $this->result;
    }

    /**
     * @brief get response of logic if succeed.
     *
     * @return boolean response of logic
     */
    public function &getSuccess()
    {
        return $this->success;
    }

    /**
     * @brief get error informatino of logic if failed.
     *
     * @return boolean error
     */
    public function &getError()
    {
        return $this->error;
    }

    /**
     * @brief add error code and error message
     *
     * @param int    $code  error code
     * @param string $extra extra information of err(null if omitted)
     */
    public function addError($code, $extra = null)
    {
        $this->error->add($code, $extra);
    }

    /**
     * @brief set error informatino of logic if failed.
     *
     * @param bool $result
     */
    public function setResult($result)
    {
        $this->result = $result;
    }

    /**
     * @brief set error informatino of logic if failed.
     *
     * @param mixed $success
     */
    public function setSuccess(&$success)
    {
        $this->success = &$success;
    }
}
